@@ -26,7 +26,6 @@ from gettext import gettext as _
 from gi.repository import Gdk, GObject, Gtk, Pango
 
 from gnomemusic.coresong import CoreSong
-from gnomemusic.player import PlayerPlaylist
 from gnomemusic.utils import SongStateIcon
 from gnomemusic.widgets.starhandlerwidget import StarHandlerWidget
 
@@ -114,7 +113,7 @@ class SongsView(Gtk.ScrolledWindow):
         """
         return self._selection_mode
 
-    @selection_mode.setter
+    @selection_mode.setter  # type: ignore
     def selection_mode(self, value):
         """selection-mode setter
 
@@ -151,8 +150,7 @@ class SongsView(Gtk.ScrolledWindow):
 
         itr = self._model.get_iter(path)
         coresong = self._model[itr][7]
-        self._coremodel.set_player_model(
-            PlayerPlaylist.Type.SONGS, self._model)
+        self._coremodel.props.active_core_object = coresong
 
         self._player.play(coresong)
 
@@ -203,6 +201,16 @@ class SongsView(Gtk.ScrolledWindow):
 
         return False
 
+    @GObject.Property(
+        type=Gtk.ListStore, default=None, flags=GObject.ParamFlags.READABLE)
+    def model(self):
+        """Get songs view model
+
+        :returns: songs view model
+        :rtype: Gtk.ListStore
+        """
+        return self._model
+
     def _select(self, value):
         with self._model.freeze_notify():
             itr = self._model.iter_children(None)
