@@ -24,7 +24,7 @@
 
 from gi.repository import GObject, Gtk
 
-from gnomemusic.albumartcache import Art
+from gnomemusic.utils import ArtSize
 from gnomemusic.widgets.disclistboxwidget import DiscBox
 from gnomemusic.widgets.songwidget import SongWidget
 
@@ -40,7 +40,7 @@ class ArtistAlbumWidget(Gtk.Box):
     __gtype_name__ = 'ArtistAlbumWidget'
 
     _album_box = Gtk.Template.Child()
-    _cover_stack = Gtk.Template.Child()
+    _art_stack = Gtk.Template.Child()
     _disc_list_box = Gtk.Template.Child()
     _title_year = Gtk.Template.Child()
 
@@ -66,8 +66,8 @@ class ArtistAlbumWidget(Gtk.Box):
 
         self._selection_mode = False
 
-        self._cover_stack.props.size = Art.Size.MEDIUM
-        self._cover_stack.update(corealbum)
+        self._art_stack.props.size = ArtSize.MEDIUM
+        self._art_stack.props.coreobject = corealbum
 
         self.bind_property(
             'selection-mode', self._disc_list_box, 'selection-mode',
@@ -83,7 +83,7 @@ class ArtistAlbumWidget(Gtk.Box):
             self._size_group.add_widget(self._album_box)
 
         if self._cover_size_group:
-            self._cover_size_group.add_widget(self._cover_stack)
+            self._cover_size_group.add_widget(self._art_stack)
 
         corealbum.props.model.connect_after(
             "items-changed", self._on_model_items_changed)
@@ -107,7 +107,8 @@ class ArtistAlbumWidget(Gtk.Box):
         n_items = model.get_n_items()
         for i in range(n_items):
             discbox = self._disc_list_box.get_row_at_index(i)
-            discbox.props.show_disc_label = (n_items > 1)
+            if discbox is not None:
+                discbox.props.show_disc_label = (n_items > 1)
 
     def _song_activated(self, widget, song_widget):
         if self.props.selection_mode:
