@@ -44,28 +44,28 @@ class SelectionBarMenuButton(Gtk.MenuButton):
     def __init__(self):
         super().__init__()
 
-        self._selected_items_count = 0
+        self._selected_songs_count = 0
 
     @GObject.Property(type=int, default=0, minimum=0)
-    def selected_items_count(self):
-        """The number of items selected
+    def selected_songs_count(self):
+        """The number of songs selected
 
-        :returns: Number of items selected
+        :returns: Number of songs selected
         :rtype: int
         """
-        return self._selected_items_count
+        return self._selected_songs_count
 
-    @selected_items_count.setter
-    def selected_items_count(self, value):
-        """Set the number of items selected
+    @selected_songs_count.setter  # type: ignore
+    def selected_songs_count(self, value):
+        """Set the number of songs selected
 
-        :param int value: The number of items selected
+        :param int value: The number of songs selected
         """
-        self._selected_items_count = value
+        self._selected_songs_count = value
 
         if value > 0:
             text = ngettext(
-                "Selected {} item", "Selected {} items", value).format(value)
+                "Selected {} song", "Selected {} songs", value).format(value)
             self._menu_label.props.label = text
         else:
             self._menu_label.props.label = _("Click on items to select them")
@@ -95,7 +95,7 @@ class HeaderBar(Gtk.HeaderBar):
     _menu_button = Gtk.Template.Child()
 
     search_mode_active = GObject.Property(type=bool, default=False)
-    selected_items_count = GObject.Property(type=int, default=0, minimum=0)
+    selected_songs_count = GObject.Property(type=int, default=0, minimum=0)
     selection_mode_allowed = GObject.Property(type=bool, default=True)
     stack = GObject.Property(type=Gtk.Stack)
 
@@ -133,12 +133,16 @@ class HeaderBar(Gtk.HeaderBar):
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
         self.bind_property(
-            "selected-items-count", self._selection_menu,
-            "selected-items-count")
+            "selected-songs-count", self._selection_menu,
+            "selected-songs-count")
         self.bind_property(
             "search-mode-active", self._search_button, "active",
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
+        self.bind_property(
+            "selection-mode", self._search_button, "visible",
+            GObject.BindingFlags.INVERT_BOOLEAN
+            | GObject.BindingFlags.SYNC_CREATE)
 
         self.connect(
             "notify::selection-mode-allowed",
@@ -153,7 +157,7 @@ class HeaderBar(Gtk.HeaderBar):
         """
         return self._selection_mode
 
-    @selection_mode.setter
+    @selection_mode.setter  # type: ignore
     def selection_mode(self, mode):
         """Set the selection mode
 
@@ -178,7 +182,7 @@ class HeaderBar(Gtk.HeaderBar):
         """
         return self._state
 
-    @state.setter
+    @state.setter  # type: ignore
     def state(self, value):
         """Set state of the of widget
 
