@@ -27,6 +27,7 @@ from gettext import gettext as _
 from gi.repository import GLib, GObject, Gtk
 
 
+@Gtk.Template(resource_path="/org/gnome/Music/ui/NotificationsPopup.ui")
 class NotificationsPopup(Gtk.Revealer):
     """Display notification messages as popups
 
@@ -38,28 +39,16 @@ class NotificationsPopup(Gtk.Revealer):
 
     __gtype_name__ = "NotificationsPopup"
 
+    _grid = Gtk.Template.Child()
+
     def __init__(self):
         super().__init__()
 
-        self._setup_view()
-
-    def _setup_view(self):
-        frame = Gtk.Frame()
-        frame.get_style_context().add_class('app-notification')
-        self.add(frame)
-
-        self._grid = Gtk.Grid(
-            row_spacing=6, orientation=Gtk.Orientation.VERTICAL)
-        frame.add(self._grid)
-
         self._loading_notification = LoadingNotification()
         self._loading_notification.connect('visible', self._set_visibility)
         self._loading_notification.connect('invisible', self._set_visibility)
         self._grid.add(self._loading_notification)
 
-        self.show_all()
-        self._loading_notification.hide()
-
     def _hide_notifications(self, notification, remove):
         if remove:
             self._grid.remove(notification)
@@ -128,6 +117,7 @@ class NotificationsPopup(Gtk.Revealer):
                 notification._finish_deletion()
 
 
+@Gtk.Template(resource_path="/org/gnome/Music/ui/LoadingNotification.ui")
 class LoadingNotification(Gtk.Grid):
     """LoadingNotification displays a loading notification message
 
@@ -140,20 +130,13 @@ class LoadingNotification(Gtk.Grid):
         'invisible': (GObject.SignalFlags.RUN_FIRST, None, ())
     }
 
+    __gtype_name__ = "LoadingNotification"
+
     def __init__(self):
-        super().__init__(column_spacing=18)
+        super().__init__()
         self._counter = 0
         self._timeout_id = 0
 
-        spinner = Gtk.Spinner()
-        spinner.start()
-        self.add(spinner)
-
-        label = Gtk.Label(
-            label=_("Loading"), halign=Gtk.Align.START, hexpand=True)
-        self.add(label)
-        self.show_all()
-
     def pop(self):
         """Decrease the counter. Hide notification if it reaches 0."""
         self._counter = self._counter - 1
@@ -169,7 +152,7 @@ class LoadingNotification(Gtk.Grid):
     def push(self):
         """Increase the counter. Start notification if necessary."""
         def callback():
-            self.show_all()
+            self.props.visible = True
             self.emit('visible')
 
         if self._counter == 0:
@@ -180,6 +163,7 @@ class LoadingNotification(Gtk.Grid):
         self._counter = self._counter + 1
 
 
+@Gtk.Template(resource_path="/org/gnome/Music/ui/PlaylistNotification.ui")
 class PlaylistNotification(Gtk.Grid):
     """Show a notification on playlist or song deletion.
 
@@ -187,43 +171,40 @@ class PlaylistNotification(Gtk.Grid):
     to the NotificationsPopup.
     """
 
+    __gtype_name__ = "PlaylistNotification"
+
+    _label = Gtk.Template.Child()
+
     class Type(IntEnum):
         """Enum for Playlists Notifications"""
         PLAYLIST = 0
         SONG = 1
 
     def __init__(
-            self, notifications_popup, coremodel, type_, playlist,
+            self, notifications_popup, application, type_, playlist,
             position=None, coresong=None):
         """Creates a playlist deletion notification popup (song or playlist)
 
-        :param GtkRevealer: notifications_popup: the popup object
-        :param CoreModel: core model
-        :param type_: NotificationType (song or playlist)
+        :param GtkRevealer notifications_popup: the popup object
+        :param Application application: application object
+        :param enum type_: NotificationType (song or playlist)
         :param Playlist playlist: playlist
         :param int position: position of the object to delete
         :param object coresong: CoreSong for song deletion
         """
-        super().__init__(column_spacing=18)
+        super().__init__()
         self._notifications_popup = notifications_popup
-        self._coremodel = coremodel
+        self._coregrilo = application.props.coregrilo
         self.type_ = type_
         self._playlist = playlist
         self._position = position
         self._coresong = coresong
 
         message = self._create_notification_message()
-        self._label = Gtk.Label(
-            label=message, halign=Gtk.Align.START, hexpand=True)
-        self.add(self._label)
-
-        undo_button = Gtk.Button.new_with_mnemonic(_("_Undo"))
-        undo_button.connect("clicked", self._undo_deletion)
-        self.add(undo_button)
-        self.show_all()
+        self._label.props.label = message
 
         if self.type_ == PlaylistNotification.Type.PLAYLIST:
-            self._coremodel.stage_playlist_deletion(self._playlist)
+            self._coregrilo.stage_playlist_deletion(self._playlist)
         else:
             playlist.stage_song_deletion(self._coresong, position)
 
@@ -241,6 +222,7 @@ class PlaylistNotification(Gtk.Grid):
 
         return msg
 
+    @Gtk.Template.Callback()
     def _undo_deletion(self, widget_):
         """Undo deletion and remove notification"""
         if self._timeout_id > 0:
@@ -249,14 +231,22 @@ class PlaylistNotification(Gtk.Grid):
 
         self._notifications_popup.remove_notification(self)
         if self.type_ == PlaylistNotification.Type.PLAYLIST:
-            self._coremodel.finish_playlist_deletion(self._playlist, False)
+            self._coregrilo.finish_playlist_deletion(self._playlist, False)
         else:
             self._playlist.undo_pending_song_deletion(
                 self._coresong, self._position)
 
+    @Gtk.Template.Callback()
+    def _close_notification(self, widget_):
+        if self._timeout_id > 0:
+            GLib.source_remove(self._timeout_id)
+            self._timeout_id = 0
+
+        self._finish_deletion()
+
     def _finish_deletion(self):
         self._notifications_popup.remove_notification(self)
         if self.type_ == PlaylistNotification.Type.PLAYLIST:
-            self._coremodel.finish_playlist_deletion(self._playlist, True)
+            self._coregrilo.finish_playlist_deletion(self._playlist, True)
         else:
             self._playlist.finish_song_deletion(self._coresong)
